@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -487,6 +487,29 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteMessageReceiver(self, request):
+        """删除消息接收人
+
+        :param request: Request instance for DeleteMessageReceiver.
+        :type request: :class:`tencentcloud.cam.v20190116.models.DeleteMessageReceiverRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.DeleteMessageReceiverResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteMessageReceiver", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteMessageReceiverResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteOIDCConfig(self, request):
         """删除OIDC身份提供商
 
@@ -1545,6 +1568,29 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ListReceiver(self, request):
+        """获取消息接收人列表
+
+        :param request: Request instance for ListReceiver.
+        :type request: :class:`tencentcloud.cam.v20190116.models.ListReceiverRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.ListReceiverResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListReceiver", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListReceiverResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ListSAMLProviders(self, request):
         """查询SAML身份提供商列表
 
@@ -1960,6 +2006,29 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def UpdateRoleSessionDuration(self, request):
+        """修改角色会话时长
+
+        :param request: Request instance for UpdateRoleSessionDuration.
+        :type request: :class:`tencentcloud.cam.v20190116.models.UpdateRoleSessionDurationRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.UpdateRoleSessionDurationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateRoleSessionDuration", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateRoleSessionDurationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def UpdateSAMLProvider(self, request):
         """更新SAML身份提供商信息
 
