@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -441,7 +441,7 @@ class OceanusClient(AbstractClient):
 
 
     def DescribeJobEvents(self, request):
-        """获取指定作业的事件，包括作业启动停止、运行失败、快照失败、作业异常等各种事件类型
+        """请求参数不包含 "RunningOrderIds"时，接口获取指定作业的事件，包括作业启动停止、运行失败、快照失败、作业异常等各种事件类型;请求参数不包含 "RunningOrderIds"时，接口为查询作业实例ID接口,获取作业实例
 
         :param request: Request instance for DescribeJobEvents.
         :type request: :class:`tencentcloud.oceanus.v20190422.models.DescribeJobEventsRequest`
@@ -463,6 +463,29 @@ class OceanusClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeJobRuntimeInfo(self, request):
+        """获取作业运行时的信息
+
+        :param request: Request instance for DescribeJobRuntimeInfo.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DescribeJobRuntimeInfoRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DescribeJobRuntimeInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeJobRuntimeInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeJobRuntimeInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeJobSavepoint(self, request):
         """查找Savepoint列表
 
